#!/bin/sh

#===============================================================================#
#                               uninstall.sh                                    #
#                                                                               #
#           usage : ./uninstall.sh instance name [nosave]
#                                                                               #
#    error code :   0 - installation done with succes                           #
#                   1 - instance name or/and port not supply                    #
#                   2 - instance directory not exists                           #
#                   3 - instance don't stop correctly                           #
#                   4 - cancel uninstall                                        #
#                                                                               #
#                                                                               #
#===============================================================================#

# ---- Verify that the instance name is supply ----
if [ $# -lt 1 ] ; then
   echo "[Error] Usage : ${0} [instance name]"
   exit 1
fi
instance=$1

# ------------ Define variables ---------------
if [ -f "tools_common.inc.sh" ]; then . ./tools_common.inc.sh;else echo "please run in . directory";exit 1;fi
SCRIPT_INSTANCE_HOME=$GSCRIPT_HOME/${instance}

# ---- Confirm instance uninstall ----
echo "Do you really want to remove instance ${instance} ? (y/n):"
read a
if [ $a != y ]; then
echo "[info] Exit uninstall"
exit 4
fi

# ----- Test if instance directory exists --------
if [ ! -d "${SCRIPT_INSTANCE_HOME}" ]; then
    echo "[Notice] Instance directory ${SCRIPT_INSTANCE_HOME} not exists"
    exit 2
fi

# --------- Stop Instance -----------
echo "[info] watch if instance is started ..."
${SCRIPT_INSTANCE_HOME}/stop_${GSCRIPT_APPLI}_${instance}.sh

sh install_logrotate_${GSCRIPT_APPLI}.sh ${instance} uninstall
sh install_startup_${GSCRIPT_APPLI}.sh ${instance} uninstall

if [ "$2" != "nosave" ]; then
	echo "[info] save content in $GSCRIPT_HOME/${instance}.tgz"
	tar cf - $GSCRIPT_HOME/${instance}/ | gzip -c > $GSCRIPT_HOME/${instance}.tgz
fi

# ------------ Remove directory -------------

sudo $GSCRIPT_MOTEUR/tools/install_removelogs.sh "${GSCRIPT_HOME}/$instance/" uninstall

echo "[info] remove directory ${SCRIPT_INSTANCE_HOME} ..."
rm -rf ${SCRIPT_INSTANCE_HOME}
echo "[info] directory removed"

echo "[info] uninstall finished"

